==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/orbital/kotlin/inputs/ListSpacecraftAvailableContactsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.orbital.kotlin.inputs

import com.pulumi.azurenative.orbital.inputs.ListSpacecraftAvailableContactsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property contactProfile The reference to the contact profile resource.
 * @property endTime End time of a contact (ISO 8601 UTC standard).
 * @property groundStationName Name of Azure Ground Station.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property spacecraftName Spacecraft ID.
 * @property startTime Start time of a contact (ISO 8601 UTC standard).
 */
public data class ListSpacecraftAvailableContactsPlainArgs(
    public val contactProfile: ContactParametersContactProfile,
    public val endTime: String,
    public val groundStationName: String,
    public val resourceGroupName: String,
    public val spacecraftName: String,
    public val startTime: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.orbital.inputs.ListSpacecraftAvailableContactsPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.orbital.inputs.ListSpacecraftAvailableContactsPlainArgs =
        com.pulumi.azurenative.orbital.inputs.ListSpacecraftAvailableContactsPlainArgs.builder()
            .contactProfile(contactProfile.let({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .endTime(endTime.let({ args0 -> args0 }))
            .groundStationName(groundStationName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .spacecraftName(spacecraftName.let({ args0 -> args0 }))
            .startTime(startTime.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListSpacecraftAvailableContactsPlainArgs].
 */
@PulumiTagMarker
public class ListSpacecraftAvailableContactsPlainArgsBuilder internal constructor() {
    private var contactProfile: ContactParametersContactProfile? = null

    private var endTime: String? = null

    private var groundStationName: String? = null

    private var resourceGroupName: String? = null

    private var spacecraftName: String? = null

    private var startTime: String? = null

    /**
     * @param value The reference to the contact profile resource.
     */
    @JvmName("qljceiqdwskdatci")
    public suspend fun contactProfile(`value`: ContactParametersContactProfile) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.contactProfile = mapped
    }

    /**
     * @param argument The reference to the contact profile resource.
     */
    @JvmName("vvfbluujngrbdlru")
    public suspend
    fun contactProfile(argument: suspend ContactParametersContactProfileBuilder.() -> Unit) {
        val toBeMapped = ContactParametersContactProfileBuilder().applySuspend { argument() }.build()
        val mapped = toBeMapped
        this.contactProfile = mapped
    }

    /**
     * @param value End time of a contact (ISO 8601 UTC standard).
     */
    @JvmName("lmpfswtnmovygvxr")
    public suspend fun endTime(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.endTime = mapped
    }

    /**
     * @param value Name of Azure Ground Station.
     */
    @JvmName("efbsuqpolwelwgbn")
    public suspend fun groundStationName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.groundStationName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("fsoqfxpyaqxohkkr")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Spacecraft ID.
     */
    @JvmName("qxulxqrodsddmtel")
    public suspend fun spacecraftName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.spacecraftName = mapped
    }

    /**
     * @param value Start time of a contact (ISO 8601 UTC standard).
     */
    @JvmName("swwflrgenanqcnds")
    public suspend fun startTime(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.startTime = mapped
    }

    internal fun build(): ListSpacecraftAvailableContactsPlainArgs =
        ListSpacecraftAvailableContactsPlainArgs(
            contactProfile = contactProfile ?: throw PulumiNullFieldException("contactProfile"),
            endTime = endTime ?: throw PulumiNullFieldException("endTime"),
            groundStationName = groundStationName ?: throw PulumiNullFieldException("groundStationName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            spacecraftName = spacecraftName ?: throw PulumiNullFieldException("spacecraftName"),
            startTime = startTime ?: throw PulumiNullFieldException("startTime"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/orbital/kotlin/inputs/ListSpacecraftAvailableContactsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.orbital.kotlin.inputs

import com.pulumi.azurenative.orbital.inputs.ListSpacecraftAvailableContactsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property contactProfile The reference to the contact profile resource.
 * @property endTime End time of a contact (ISO 8601 UTC standard).
 * @property groundStationName Name of Azure Ground Station.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property spacecraftName Spacecraft ID.
 * @property startTime Start time of a contact (ISO 8601 UTC standard).
 */
public data class ListSpacecraftAvailableContactsPlainArgs(
    public val contactProfile: ContactParametersContactProfile,
    public val endTime: String,
    public val groundStationName: String,
    public val resourceGroupName: String,
    public val spacecraftName: String,
    public val startTime: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.orbital.inputs.ListSpacecraftAvailableContactsPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.orbital.inputs.ListSpacecraftAvailableContactsPlainArgs =
        com.pulumi.azurenative.orbital.inputs.ListSpacecraftAvailableContactsPlainArgs.builder()
            .contactProfile(contactProfile.let({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .endTime(endTime.let({ args0 -> args0 }))
            .groundStationName(groundStationName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .spacecraftName(spacecraftName.let({ args0 -> args0 }))
            .startTime(startTime.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListSpacecraftAvailableContactsPlainArgs].
 */
@PulumiTagMarker
public class ListSpacecraftAvailableContactsPlainArgsBuilder internal constructor() {
    private var contactProfile: ContactParametersContactProfile? = null

    private var endTime: String? = null

    private var groundStationName: String? = null

    private var resourceGroupName: String? = null

    private var spacecraftName: String? = null

    private var startTime: String? = null

    /**
     * @param value The reference to the contact profile resource.
     */
    @JvmName("myxncxowvploigaj")
    public suspend fun contactProfile(`value`: ContactParametersContactProfile) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.contactProfile = mapped
    }

    /**
     * @param argument The reference to the contact profile resource.
     */
    @JvmName("mbwgsnmwvyiokyii")
    public suspend
    fun contactProfile(argument: suspend ContactParametersContactProfileBuilder.() -> Unit) {
        val toBeMapped = ContactParametersContactProfileBuilder().applySuspend { argument() }.build()
        val mapped = toBeMapped
        this.contactProfile = mapped
    }

    /**
     * @param value End time of a contact (ISO 8601 UTC standard).
     */
    @JvmName("igstksbqayqdditr")
    public suspend fun endTime(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.endTime = mapped
    }

    /**
     * @param value Name of Azure Ground Station.
     */
    @JvmName("otewtsrowgiygbkf")
    public suspend fun groundStationName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.groundStationName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("yqmndkaqngrhgfqn")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Spacecraft ID.
     */
    @JvmName("jknlkwfrxalqrimq")
    public suspend fun spacecraftName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.spacecraftName = mapped
    }

    /**
     * @param value Start time of a contact (ISO 8601 UTC standard).
     */
    @JvmName("fknfvobgfqxxflfa")
    public suspend fun startTime(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.startTime = mapped
    }

    internal fun build(): ListSpacecraftAvailableContactsPlainArgs =
        ListSpacecraftAvailableContactsPlainArgs(
            contactProfile = contactProfile ?: throw PulumiNullFieldException("contactProfile"),
            endTime = endTime ?: throw PulumiNullFieldException("endTime"),
            groundStationName = groundStationName ?: throw PulumiNullFieldException("groundStationName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            spacecraftName = spacecraftName ?: throw PulumiNullFieldException("spacecraftName"),
            startTime = startTime ?: throw PulumiNullFieldException("startTime"),
        )
}
